Kopis1024SecretKey

Struct Kopis1024SecretKey 

pub struct Kopis1024SecretKey(/* private fields */);
A secret key for this KEM

Implementations

Source

impl Kopis1024SecretKey

pub fn generate(rng: &mut impl CryptoRng) -> Self

Generate a fresh secret key

pub fn seed(&self) -> &[u8; 32]

Returns the seed that produced this secret key

pub fn expand_from_seed(bytes: &[u8; 32]) -> Self

Deserializes a secret key from a 32-byte seed

pub fn public_key(&self) -> Kopis1024PublicKey

Returns the public key corresponding to this secret key

Source

impl Kopis1024SecretKey

pub fn decapsulate( &self, encapsulated_key: &Kopis1024Ciphertext, ) -> SharedSecret

Decapsulates an encapsulated key and returns the resulting shared secret. If the encapsulated key is invalid, then the shared secret will be pseudorandom garbage.